"""
Interfaces for casa_envoy
"""
import abc
from abc import ABC
from typing import Dict


class LauncherIF(ABC):
    """
    Generic Launcher methods.
    Should be implemented for any type of CASA processing.
    """

    @abc.abstractmethod
    def launch_casa(self):
        pass

    @abc.abstractmethod
    def run_audit(self, parameters: Dict[str, str]):
        pass


class AuditorIF(ABC):
    """
    Generic functionality implementation for auditor classes
    """

    @abc.abstractmethod
    def audit(self):
        pass


class FoundationIF(ABC):
    """
    Generic Foundation methods
    Should be implemented for any type of CASA processing that requires initial data placement
    in locations other than rawdata after download
    """

    @abc.abstractmethod
    def data_foundation(self):
        pass
