import inspect
import logging
from argparse import Namespace
from typing import List

from pycapo import CapoConfig

from . import intercessions, resolutions


def set_option(nsp: Namespace) -> List[str]:
    options = vars(nsp)
    for key in options:
        field = options.get(key)
        if field is not None:
            intervention = key
            request_id = field[0]
            return [intervention, request_id]


class Arbiter:
    """
    Class that intercedes with running requests
    """

    def __init__(self, nsp: Namespace):
        self.logger = logging.getLogger("mediator")
        key_list = set_option(nsp)
        self.intervention = key_list[0]
        self.request_id = key_list[1]
        self.url = CapoConfig().settings("edu.nrao.workspaces.WorkflowSettings").serviceUrl

    def intercede(self):
        """
        Retrieve function list of possible intercessions and execute desired intervention

        :return:
        """
        possible_intercessions = inspect.getmembers(intercessions)

        for name, function in possible_intercessions:
            if name == self.intervention:
                self.logger.info(f"Interceding with {self.intervention} on request #{self.request_id}...")
                function(self.url, self.request_id)

        self.resolve()

    def resolve(self):
        """
        Retrieve function list of possible resolutions and execute correct type

        :return:
        """
        self.logger.info("Resolving...")
        possible_resolutions = inspect.getmembers(resolutions)

        for name, function in possible_resolutions:
            if name == self.intervention:
                function(self.url, self.request_id)
