"""multistage calibration

Revision ID: 47368b3802a9
Revises: 0ec2cf8302a9
Create Date: 2021-10-04 14:39:31.364125

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "47368b3802a9"
down_revision = "0ec2cf8302a9"
branch_labels = None
depends_on = None


dag_content = """JOB FETCH std_calibration_fetch.condor
VARS FETCH jobname="$(JOB)"

JOB ENVOY std_calibration_envoy.condor
VARS ENVOY jobname="$(JOB)"

JOB CONVEY std_calibration_convey.condor
VARS CONVEY jobname="$(JOB)"

PARENT FETCH CHILD ENVOY
PARENT ENVOY CHILD CONVEY
"""

fetch_content = """executable = std_calibration_fetch.sh
arguments = {{product_locator}}

output = calibration_fetch.out
error = calibration_fetch.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher
transfer_output_files = working, rawdata, products

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue
"""

envoy_content = """executable = std_calibration_envoy.sh
arguments = metadata.json PPR.xml

output = calibration_envoy.out
error = calibration_envoy.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, ./working, ./rawdata, ./products, ./PPR.xml, ./metadata.json{{files_to_transfer}}
transfer_output_files = working, rawdata, products

request_memory = {{ramInGb}}
getenv = True

{{^remote}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote}}
{{#remote}}
requirements = (VLASS == True)
+partition = "VLASS"
Rank = (TARGET.VLASS == True) + (TARGET.VLASSTEST =!= True)
{{/remote}}

queue
"""

convey_content = """executable = std_calibration_convey.sh
arguments = metadata.json

output = calibration_convey.out
error = calibration_convey.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/conveyor, ./metadata.json, ./working, ./rawdata, ./products


getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue
"""


old_content = """executable = std_calibration.sh
arguments = {{product_locator}} {{request_id}} metadata.json PPR.xml

output = calibration.out
error = calibration.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, $(SBIN_PATH)/conveyor, ./PPR.xml, ./metadata.json{{files_to_transfer}}
# results are delivered to QA area by conveyor script, no need to transfer
# transfer_output_files = working, rawdata, products

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue

"""


def upgrade():
    op.execute(
        """
        DELETE FROM workflow_templates WHERE filename='std_calibration.condor'
        """
    )

    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('std_calibration.dag', E'{dag_content}', 'std_calibration') 
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('std_calibration_fetch.condor', E'{fetch_content}', 'std_calibration') 
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('std_calibration_envoy.condor', E'{envoy_content}', 'std_calibration') 
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('std_calibration_convey.condor', E'{convey_content}', 'std_calibration') 
        """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflow_templates 
        WHERE filename like ('std_calibration_%.condor') 
        AND workflow_name = 'std_calibration'
        """
    )

    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('std_calibration.condor', E'{old_content}', 'std_calibration')
        """
    )
