"""calibration delivery

Revision ID: 69cf6d10dc00
Revises: 4ea5c19c9ebd
Create Date: 2021-06-15 14:13:47.942201

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "69cf6d10dc00"
down_revision = "4ea5c19c9ebd"
branch_labels = None
depends_on = None


def upgrade():
    op.execute(
        """
        UPDATE workflow_templates
        SET content=E'executable = std_calibration.sh
arguments = {{product_locator}} {{request_id}} metadata.json PPR.xml

output = calibration.out
error = calibration.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, $(SBIN_PATH)/conveyor, ./PPR.xml, ./metadata.json
# results are delivered to QA area by conveyor script, no need to transfer
# transfer_output_files = working, rawdata, products

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue
' 
        WHERE filename='std_calibration.condor' and workflow_name='std_calibration'
        """
    )

    op.execute(
        """
        UPDATE workflow_templates
        SET content=E'#!/bin/sh

export HOME=$TMPDIR

./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1
cd ../
./casa_envoy --standard-cal $3 $4
./conveyor --deliver $3
'
        WHERE filename='std_calibration.sh' and workflow_name='std_calibration'
        """
    )


def downgrade():
    op.execute(
        """
        UPDATE workflow_templates
        SET content=E'executable = std_calibration.sh
arguments = {{product_locator}} {{request_id}} metadata.json PPR.xml

output = calibration.out
error = calibration.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/deliver-cipl.sh, ./PPR.xml, ./metadata.json
transfer_output_files = working, rawdata, products

request_memory = 48G
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue
' 
        WHERE filename='std_calibration.condor' and workflow_name='std_calibration'
        """
    )

    op.execute(
        """
        UPDATE workflow_templates
        SET content=E'#!/bin/sh

export HOME=$TMPDIR

./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1
cd ../
./casa_envoy --standard-cal $3 $4
'
        """
    )
