"""multistage calibration scripts

Revision ID: bd5f8a4c61da
Revises: 47368b3802a9
Create Date: 2021-10-04 16:12:48.550412

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "bd5f8a4c61da"
down_revision = "47368b3802a9"
branch_labels = None
depends_on = None


fetch_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1
cd ../

"""

envoy_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR
{{#remote}}
export CAPO_PATH=$(readlink -f $TMPDIR)
export CAPO_PROFILE={{profile}}
{{/remote}}

./casa_envoy --standard-cal $1 $2

"""

convey_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

./conveyor --deliver $1
"""

old_content = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit
./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1
cd ../
./casa_envoy --standard-cal $3 $4
./conveyor --deliver $3

"""


def upgrade():
    op.execute(
        """
        DELETE FROM workflow_templates WHERE filename='std_calibration.sh'
        """
    )
    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name) 
            VALUES ('std_calibration_fetch.sh', E'{fetch_content}', 'std_calibration') 
            """
    )
    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name) 
            VALUES ('std_calibration_envoy.sh', E'{envoy_content}', 'std_calibration') 
            """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('std_calibration_convey.sh', E'{convey_content}', 'std_calibration') 
        """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflow_templates 
        WHERE filename like ('std_calibration_%.sh') 
        AND workflow_name = 'std_calibration'
        """
    )

    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('std_calibration.sh', E'{old_content}', 'std_calibration')
        """
    )
