"""multistage std cms imaging

Revision ID: ec5653e2ec49
Revises: bd32e3fa12ac
Create Date: 2021-10-11 09:06:03.266387

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "ec5653e2ec49"
down_revision = "bd32e3fa12ac"
branch_labels = None
depends_on = None

dag_content = """JOB ENVOY std_cms_imaging_envoy.condor
VARS ENVOY jobname="$(JOB)"

JOB CONVEY std_cms_imaging_convey.condor
VARS CONVEY jobname="$(JOB)"

PARENT ENVOY CHILD CONVEY
"""

envoy_content = """executable = std_cms_imaging_envoy.sh
arguments = metadata.json PPR.xml

output = imaging_envoy.out
error = imaging_envoy.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
CMS_PATH = {{cms_path}}
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela{{#remote}}, {{profile}}.properties{{/remote}}, ./PPR.xml, ./metadata.json, $(CMS_PATH)/{{sdmId}}.ms{{files_to_transfer}}
transfer_output_files = working, rawdata, products

request_memory = {{ramInGb}}
getenv = True
{{^remote}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote}}
{{#remote}}
requirements = (VLASS == True)
+partition = "VLASS"
Rank = (TARGET.VLASS == True) + (TARGET.VLASSTEST =!= True)
{{/remote}}

queue
"""

convey_content = """executable = std_cms_imaging_convey.sh
arguments = metadata.json

output = imaging_convey.out
error = imaging_convey.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
CMS_PATH = {{cms_path}}
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/conveyor, ./metadata.json, ./working, ./rawdata, ./products

getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue
"""

old_content = """executable = std_cms_imaging.sh
arguments = metadata.json PPR.xml

output = imaging.out
error = imaging.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
CMS_PATH = {{cms_path}}
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, $(SBIN_PATH)/conveyor, ./PPR.xml, ./metadata.json, $(CMS_PATH)/{{sdmId}}.ms{{files_to_transfer}}

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue
"""


def upgrade():
    op.execute(
        """
        DELETE FROM workflow_templates WHERE filename='std_cms_imaging.condor'
        """
    )

    op.execute(
        f"""
                INSERT INTO workflow_templates (filename, content, workflow_name) 
                VALUES ('std_cms_imaging.dag', E'{dag_content}', 'std_cms_imaging') 
                """
    )
    op.execute(
        f"""
                INSERT INTO workflow_templates (filename, content, workflow_name) 
                VALUES ('std_cms_imaging_envoy.condor', E'{envoy_content}', 'std_cms_imaging') 
                """
    )
    op.execute(
        f"""
                INSERT INTO workflow_templates (filename, content, workflow_name) 
                VALUES ('std_cms_imaging_convey.condor', E'{convey_content}', 'std_cms_imaging') 
                """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflow_templates 
        WHERE filename like ('std_cms_imaging_%.condor') 
        AND workflow_name = 'std_cms_imaging'
        """
    )

    op.execute(
        f"""
                INSERT INTO workflow_templates (filename, content, workflow_name) 
                VALUES ('std_cms_imaging.condor', E'{old_content}', 'std_cms_imaging')
                """
    )
