import logging

from immutable_views import DictView

from workspaces.capability.schema_interfaces import CapabilityExecutionIF, CapabilityRequestIF
from workspaces.shared_interfaces import MessageArchitectIF

logger = logging.getLogger(__name__)

"""
Class which creates an immutable dictionary of amqp message templates for easy access
"""

# DictView(Dict[msg_type, msg_content]
service_templates = DictView(
    {
        "capability": {
            "service": "capability",
            "routing_key": "capability",
            "subject": None,
        }
    }
)

capability_msg_templates = DictView(
    {
        "capability_submitted": {
            "type": "capability-submitted",
        },
        "capability_complete": {
            "type": "capability-complete",
        },
        "capability_failed": {
            "type": "capability-failed",
        },
        "execution_failed": {
            "type": "execution-failed",
        },
        "execution_complete": {
            "type": "execution-complete",
        },
    }
)


class CapabilityMessageArchitect(MessageArchitectIF):
    def __init__(self, execution: CapabilityExecutionIF = None, request: CapabilityRequestIF = None):
        self.subject = execution or request

    @staticmethod
    def get_message_template(msg_type: str) -> dict:
        return {**service_templates["capability"], **capability_msg_templates[msg_type]}

    def compose_message(self, msg_type: str) -> DictView:
        template = self.get_message_template(msg_type)
        template = template.copy()
        template["subject"] = self.subject
        return DictView(template)
